@@ -11,7 +11,7 @@ use String::Random qw(random_string);
 use HTML::Template;
 use base qw(Lemonldap::NG::Portal::_OpenIDConnect);
 
-our $VERSION = '1.9.8';
+our $VERSION = '1.9.9';
 
 ## @method void issuerDBInit()
 # Get configuration data
@@ -156,7 +156,7 @@ sub issuerForUnAuthUser {
         }
 
         # Get RP
-        if ( $oidc_request->{'client_id'} ) {
+        if ( my $client_id = $oidc_request->{'client_id'} ) {
             my $rp = $self->getRP($client_id);
             $ENV{"llng_oidc_rp"} = $rp if $rp;
         }
@@ -200,7 +200,7 @@ sub issuerForUnAuthUser {
             ->{oidcRPMetaDataOptionsClientSecret} )
         {
             $self->lmLog( "Wrong credentials", "error" );
-            $self->returnJSONError("access_denied");
+            $self->returnJSONError("unauthorized_client");
             $self->quit;
         }
 
